@@ -19,16 +19,26 @@ import logging
 from datetime import datetime
 from typing import Dict
 
-from providers.eskom import Province, Stage, Suburb, Provider, ProviderError
+from load_shedding.providers.eskom import Province, Stage, Suburb, Provider, ProviderError
 
 
 class ScheduleError(Exception):
     pass
 
 
-def get_suburb_schedule(provider: Provider, province: Province, suburb: Suburb, cached: bool = True) -> Dict[Stage, list]:
+def get_schedule(provider: Provider, province: Province, suburb: Suburb, stage: Stage = None, cached: bool = True) -> Dict[Stage, list]:
     stage_schedule = {}
 
+    if stage in [None, Stage.UNKNOWN]:
+        try:
+            stage = provider.get_stage()
+        except ProviderError as e:
+            logging.log(logging.ERROR, "Unable to get stage from {provider}. {e}".format(provider=provider, e=e))
+            raise e
+
+    if stage in [None, Stage.UNKNOWN, Stage.NO_LOAD_SHEDDING]:
+        raise ScheduleError("{stage}".format(stage=Stage.NO_LOAD_SHEDDING))
+
     if cached:
         try:
             cache_file = ".cache/{suburb_id}.json".format(suburb_id=suburb.id)
@@ -57,33 +67,6 @@ def get_suburb_schedule(provider: Provider, province: Province, suburb: Suburb,
             raise e
     return stage_schedule
 
-
-def get_schedule(provider: Provider, province: Province, suburb: Suburb, stage: Stage = None, cached: bool = True) -> Dict[int, list]:
-    if stage in [None, Stage.UNKNOWN]:
-        try:
-            stage = provider.get_stage()
-        except ProviderError as e:
-            logging.log(logging.ERROR, "Unable to get stage from {provider}. {e}".format(provider=provider, e=e))
-            raise e
-
-    if stage in [None, Stage.UNKNOWN, Stage.NO_LOAD_SHEDDING]:
-        raise ScheduleError("{stage}".format(stage=Stage.NO_LOAD_SHEDDING))
-
-    suburb_schedule = get_suburb_schedule(provider, province, suburb, cached=cached)
-    return suburb_schedule.get(stage.value)
-
-
-def get_schedule_by_suburb_id(provider: Provider, province: Province, suburb_id: int, stage: Stage = None, cached: bool = True) -> Dict[int, list]:
-    suburb = Suburb(id=suburb_id)
-    try:
-        schedule = get_schedule(provider, province=province, suburb=suburb, stage=stage, cached=cached)
-    except ScheduleError as e:
-        logging.log(logging.ERROR, "Unable to get schedule. {e}".format(e=e))
-        raise e
-
-    return schedule
-
-
 def list_to_dict(schedule: list) -> Dict:
     schedule_dict = {}
     now = datetime.now()
