@@ -76,6 +76,11 @@ class Province(Province):
         self.id = kwargs.get("Id", kwargs.get("id"))
         self.name = kwargs.get("Name", kwargs.get("name"))
 
+    def __str__(self):
+        return str(self.name)
+
+    def __repr__(self):
+        return self.id, self.name
 
 class Stage(Enum):
     UNKNOWN = -1
